.. include:: ../README.rst

The documents are ordered in the way they should be read:

.. toctree::
   :maxdepth: 2

   mustread/index
   advanced/index
   informative/index
   widgets/index




=================
API Documentation
=================

.. toctree::
   :maxdepth: 2

   interfaces

===========
Development
===========

.. toctree::
   :maxdepth: 1

   changelog
   authors
   todos


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
